==> dkist_processing_cryonirsp-0.0.17rc2.tar.gz: dkist_processing_cryonirsp-0.0.17rc2/dkist_processing_cryonirsp/parsers/optical_density_filters.py <==
"""PickyBud to implement early parsing of Optical Density Filter Names."""
from typing import Hashable

from dkist_processing_common.models.flower_pot import Stem
from dkist_processing_common.models.flower_pot import Thorn

from dkist_processing_cryonirsp.models.optical_density_filter_names import (
    AllowableOpticalDensityFilterNames,
)
from dkist_processing_cryonirsp.parsers.cryonirsp_l0_fits_access import CryonirspRampFitsAccess

ALLOWABLE_OPTICAL_DENSITY_FILTERS = {f for f in AllowableOpticalDensityFilterNames}


class OpticalDensityFiltersPickyBud(Stem):
    """PickyBud to implement early parsing of Optical Density Filter Names."""

    def __init__(self):
        super().__init__(stem_name="OpticalDensityFilterNamePickyBud")

    def setter(self, fits_obj: CryonirspRampFitsAccess):
        """
        Set the optical density filter name for this fits object.

        Parameters
        ----------
        fits_obj
            The input fits obj

        Returns
        -------
        The optical density filter name associated with this fits object
        """
        return fits_obj.filter_name

    def getter(self, key: Hashable) -> Thorn:
        """Return a Thorn for valid names or raise an exception for bad names."""
        filter_names = set(self.key_to_petal_dict.values())
        bad_filter_names = filter_names.difference(ALLOWABLE_OPTICAL_DENSITY_FILTERS)
        if bad_filter_names:
            raise ValueError(f"Unknown Optical Density Filter Name(s): {bad_filter_names = }")
        return Thorn

==> dkist_processing_cryonirsp-0.0.31rc1.tar.gz: dkist_processing_cryonirsp-0.0.31rc1/dkist_processing_cryonirsp/parsers/optical_density_filters.py <==
"""PickyBud to implement early parsing of Optical Density Filter Names."""
from typing import Hashable

from dkist_processing_common.models.flower_pot import Stem
from dkist_processing_common.models.flower_pot import Thorn

from dkist_processing_cryonirsp.models.optical_density_filter_names import (
    AllowableOpticalDensityFilterNames,
)
from dkist_processing_cryonirsp.parsers.cryonirsp_l0_fits_access import CryonirspRampFitsAccess

ALLOWABLE_OPTICAL_DENSITY_FILTERS = {f for f in AllowableOpticalDensityFilterNames}


class OpticalDensityFiltersPickyBud(Stem):
    """PickyBud to implement early parsing of Optical Density Filter Names."""

    def __init__(self):
        super().__init__(stem_name="OpticalDensityFilterNamePickyBud")

    def setter(self, fits_obj: CryonirspRampFitsAccess):
        """
        Set the optical density filter name for this fits object.

        Parameters
        ----------
        fits_obj
            The input fits obj

        Returns
        -------
        The optical density filter name associated with this fits object
        """
        return fits_obj.filter_name.upper()

    def getter(self, key: Hashable) -> Thorn:
        """Return a Thorn for valid names or raise an exception for bad names."""
        filter_names = set(self.key_to_petal_dict.values())
        bad_filter_names = filter_names.difference(ALLOWABLE_OPTICAL_DENSITY_FILTERS)
        if bad_filter_names:
            raise ValueError(f"Unknown Optical Density Filter Name(s): {bad_filter_names = }")
        return Thorn
